@@ -65,12 +65,16 @@ def task_fail():
     p.tskf()
 
 def generate_key(msg):
+    c_msg = len(msg) / 32
     msg = len(msg) // 32
-    msg = 1 if msg == 0 else msg
+    if c_msg > msg:
+        msg += 1
     key = p.ikey('0' * msg * 32)
     key = p.rf(key)
     return key
 
+        
+
 def create_masterpassword(db):
     db = valid_db(db)
     while 1:
@@ -89,8 +93,8 @@ def create_masterpassword(db):
                 connect = sqlite3.connect("masterpassword.db")
                 cursor = connect.cursor()
                 cursor.execute('''create table map ( 
-                        database varchar(150) primary key ,
-                        password varchar(100) not null 
+                        database varchar(250) primary key ,
+                        password varchar(2000) not null 
                         )''')
                 cursor.execute('insert into map values (?, ?)', (db, generate_key(mpassword1)))
                 connect.commit()
@@ -130,10 +134,10 @@ def create_database(db):
     connect = sqlite3.connect(db)
     cursor = connect.cursor()
     cursor.execute('''create table passwordb ( 
-                        account varchar(150) primary key ,
-                        username varchar(100) not null ,
-                        password varchar(640),
-                        website varchar(200)
+                        account varchar(250) primary key ,
+                        username varchar(250) not null ,
+                        password varchar(2000),
+                        website varchar(250)
                         )''')
     
     create_masterpassword(db)
@@ -274,11 +278,16 @@ def view_databases():
     print("\n List of Available Databases")
     print(" ---- -- --------- ---------\n")
     filedetected = False
-    connect = sqlite3.connect('masterpassword.db')
-    cursor = connect.cursor()
-    database = cursor.execute('select database from map').fetchall()
-    cursor.close()
-    connect.close()
+
+    try:
+        connect = sqlite3.connect('masterpassword.db')
+        cursor = connect.cursor()
+        database = cursor.execute('select database from map').fetchall()
+        cursor.close()
+        connect.close()
+    except Exception as e:
+        print(' No Database Found!!!')
+
     if len(database) == 0:
         print(" No Database Found!!!")
         return
@@ -359,8 +368,8 @@ def importt(db):
         connect = sqlite3.connect("masterpassword.db")
         cursor = connect.cursor()
         cursor.execute('''create table map ( 
-                        database varchar(150) primary key ,
-                        password varchar(100) not null 
+                        database varchar(250) primary key ,
+                        password varchar(2000) not null 
                         )''')
         try:
             cursor.execute('insert into map values (?,?)', (db, password))
@@ -390,10 +399,10 @@ def importt(db):
     connect = sqlite3.connect(db)
     cursor = connect.cursor()
     cursor.execute('''create table passwordb ( 
-                        account varchar(150) primary key ,
-                        username varchar(100) not null ,
-                        password varchar(640),
-                        website varchar(200)
+                        account varchar(250) primary key ,
+                        username varchar(250) not null ,
+                        password varchar(2000),
+                        website varchar(250)
                         )''')
     
     os.chdir('..')
